| Title: | Convert Strings to Elder Futhark Runes |
|---|---|
| Description: | Convert a string of text characters to Elder Futhark Runes <https://en.wikipedia.org/wiki/Elder_Futhark>. |
| Authors: | Bryan Jenks [aut, cre] (ORCID: <https://orcid.org/0000-0002-9604-3069>) |
| Maintainer: | Bryan Jenks <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-05-12 06:22:38 UTC |
| Source: | https://github.com/tallguyjenks/runes |
runes() Converts alpha characters a-z/A-Z to runes. You can use this in
console output, scripts, RMarkdown documents, anything with Unicode/UTF-8
support.
runes(x, futhark = "elder", branch = NA, hide = FALSE)runes(x, futhark = "elder", branch = NA, hide = FALSE)
x |
a character string |
futhark |
default is "elder" for elder futhark runes, the other option is "younger" futhark as a string argument |
branch |
default is "NA" but when "younger" futhark is chosen you must specify a branch, either "short" or "long" as a string argument |
hide |
boolean option to hide non translated English alphabet characters from output. Default option hides nothing from user |
If input is a single character string then output will be a character string with unicode Elder Futhark runes replacing the 'A-Z' characters except 'q' and 'x'
cat(runes("Your Results Are: "), 7 * 49, "\n") runes("hello world") runes(x = "hello world", futhark = "elder", hide = TRUE) runes(x = "hello world", futhark = "younger", branch = "long", hide = TRUE) runes(x = "hello world", futhark = "younger", branch = "short", hide = FALSE)cat(runes("Your Results Are: "), 7 * 49, "\n") runes("hello world") runes(x = "hello world", futhark = "elder", hide = TRUE) runes(x = "hello world", futhark = "younger", branch = "long", hide = TRUE) runes(x = "hello world", futhark = "younger", branch = "short", hide = FALSE)
runes_table() returns a data.frame with 3 variable text columns.AX
runes_table(futhark = "elder", branch = NA)runes_table(futhark = "elder", branch = NA)
futhark |
which futhark set you'd like, defaults to "elder" and the argument must be a string |
branch |
if futhark is "younger" then you must also choose whether you would like short or long branch younger futhark |
The data.frame returned by this function returns 3 columns
The unicode sequence that represents the rune character.
The English a-z characters of the alphabet
The rune itself showing how it would also be displayed.
runes_table()runes_table()